BiLock

Struct BiLock 

pub struct BiLock<T>(/* private fields */);
Available on crate feature bilock only.
A lock shared by two parties.

Implementations

Source

impl<T> BiLock<T>

pub fn new(data: T) -> (Self, Self)

Creates a new BiLock wrapping the supplied data, returning two handles to it.

pub fn lock(&self) -> BiLockAcquire<'_, T>

Acquires the lock, returning a future that resolves to a guard

pub fn try_join(self, other: Self) -> Option<T>

Attempts to join two BiLocks into their original data.

pub fn join(self, other: Self) -> T

Joins two BiLocks into their original data.